@@ -18,7 +18,7 @@ use Test::BrewBuild::BrewCommands;
 use Test::BrewBuild::Dispatch;
 use Test::BrewBuild::Tester;
 
-our $VERSION = '2.10';
+our $VERSION = '2.11';
 
 my $log;
 my $bcmd;
@@ -54,7 +54,10 @@ sub new {
 sub options {
     my ($self, $args) = @_;
     my %opts;
-    my $bad_opt = _validate_opts($args);
+
+    my @arg_directives = grep {$_ =~ /^-/} @$args;
+
+    my $bad_opt = _validate_opts(\@arg_directives);
 
     GetOptionsFromArray(
         $args,
@@ -216,6 +219,7 @@ sub instance_install {
             };
             if ($@){
                 $log->_0($@);
+                $log->_1("install of $ver failed: uninstalling the remnants..");
                 $self->instance_remove($ver);
                 next;
             }
