@@ -4,7 +4,7 @@ use warnings;
 
 use version;
 
-our $VERSION = '2.10';
+our $VERSION = '2.11';
 
 my $log;
 
@@ -91,7 +91,7 @@ sub available {
 
     my @avail = $self->is_win
         ? $info =~ /(\d\.\d+\.\d+_\d+)/g
-        : $info =~ /(perl-\d\.\d+\.\d+(?:-RC\d+)?)/g;
+        : $info =~ /(?<!c)(perl-\d\.\d+\.\d+(?:-RC\d+)?)/g;
 
     @avail = $self->_legacy_perls($legacy, @avail);
 
@@ -115,7 +115,7 @@ sub remove {
 
     my $remove_cmd = $self->is_win
         ? "$self->{brew} remove"
-        : 'perlbrew uninstall';
+        : 'perlbrew --yes uninstall';
 
     $log->child('remove')->_6("remove cmd is: $remove_cmd");
 
@@ -128,7 +128,17 @@ sub is_win {
 sub _legacy_perls {
     my ($self, $legacy, @perls) = @_;
 
-    return @perls if $legacy;
+    if ($legacy) {
+        $log->child('_legacy_perls')->_7(
+            "legacy is enabled, using perls older than 5.8.9"
+        );
+        return @perls if $legacy;
+    }
+    else {
+        $log->child('_legacy_perls')->_7(
+            "legacy is disabled, ignoring perls older than 5.8.9"
+        );
+    }
 
     my @avail;
 
